/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("net.jazz.ajax.toolbox.lang.internal.Lang");

(function() {  // module container

/**
 * Raise an error if the specified is null.
 *
 * @param value		value to check
 * @param valueName	(optional) the name of this value to report at error time
 */
function checkNotNull(value, valueName) {
	if(value != null) { return; }
	
	if(valueName) {
		throw new Error(valueName + " cannot be null");
	}

	throw new Error("value cannot be null");
}

net.jazz.ajax.toolbox.lang.checkNotNull = checkNotNull;

/**
 * Raise an error if the specified string is not a non-empty string.
 * Raises an error if the specified value is null or not a string.
 * 
 * @param value		string to check
 * @param valueName	(optional) the name of this string to report at error time
 */
 function checkNotEmpty(value, valueName) {
 	if(!(dojo.trim(value).length == 0)) { return; }
 	
 	if(valueName) {
 		throw new Error(valueName + " must be a non-empty string.  Saw: " + value);
 	}
 	
 	throw new Error("value must be a non-empty string.  Saw: " + value);
 }
 
net.jazz.ajax.toolbox.lang.checkNotEmpty = checkNotEmpty;

/**
  * Return the first item of array for which the unary function, fn, returns true.
  * Returns null if array contains no such items.
  *
  * @param array	an array to search
  * @param fn 		a uniary boolean function
  */
function findIf(array, fn){

	checkNotNull(array, "array");
	checkNotNull(fn, "fn");
	
	for(i=0; i<array.length; i++) {
		if(fn(array[i])) { return array[i]; }
	}
	
	return null;
}

net.jazz.ajax.toolbox.lang.findIf = findIf;

/**
 * Raise an error unless the specified value is a non-negative number.
 * Raises an error if value is null or not a number.
 * 
 * @param value		value to check
 * @param valueName	(optional) the name of this value to report at error time
 */
function checkNonNegative(value, valueName) {
	if( value !== null && value >= 0 ) { return; }
	
	if(valueName) {
		throw new Error(valueName + " must be a non-negative number.  Saw: " + value);
	}
	throw new Error("value must be a non-negative number.  Saw: " + value);
	
}

net.jazz.ajax.toolbox.lang.checkNonNegative = checkNonNegative;

/**
 * Return a new array like <code>array</code> but without the elements for which the 
 * unary function, fn, returns true.
 * 
 * @param array	source array
 * @param fn 	a uniary boolean function
 */
function removeIf(array, fn) {
	checkNotNull(array, "array");
	checkNotNull(fn, "fn");
	
	var newArray = [];
	
	dojo.forEach( array, function(x) {
		if(!fn(x)) {
			newArray.push(x);
		}
	});
	
	return newArray;
}

net.jazz.ajax.toolbox.lang.removeIf = removeIf;

/**
 * Return a new array like <code>array</code> except elements for which the 
 * unary function, fn, returns true are replaced with <code>value</code>.
 * 
 * @param array	source array
 * @param value	value to be substituted into array
 * @param fn 	a uniary boolean function
 */
function replaceIf(array, value, fn) {
	checkNotNull(array, "array");
	checkNotNull(fn, "fn");
	
	var newArray = [];
	
	dojo.forEach( array, function(x) {
		if(fn(x)) {
			newArray.push(value);
		} else {
			newArray.push(x);
		}
	});
	
	return newArray;
}

net.jazz.ajax.toolbox.lang.replaceIf = replaceIf;

/**
 * Return true if either a or b is true but not both
 */
function xor(a, b) {
	return (a || b) && !(a && b);
}

net.jazz.ajax.toolbox.lang.xor = xor;

/**
 * Map fn onto array, three elements at a time.  fn should be a function of three
 * arguments: current, previous, and next.  Each element in array is called with
 * the current element, previous element, and next element passed to fn respectively.
 * If lst is empty, we return without making any calls, in other cases if there is no
 * previous or next element, nil is passed.
 *
 * @param fn a three-argument function to be applied to the elements of array
 * @param array
 */
function map3(array, fn) {
	checkNotNull(fn, "fn");
	checkNotNull(array, "array");
	 
	for(i=0; i < array.length; i++) {
		fn( i === 0 ? null : array[i-1], array[i], i == array.length - 1 ? null : array[i+1]);
	}
}

net.jazz.ajax.toolbox.lang.map3= map3;

})();