/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("net.jazz.ajax.ui.PlatformUI");

// TODO: Require Workbench here (see Jazz Enhancement #32401)
dojo.require("net.jazz.ajax.core.internal.loader");
dojo.require("net.jazz.ajax.core.runtime.RegistryFactory");

net.jazz.ajax.ui.PlatformUI = {
	
	// summary:
	//		central object of the Jazz Web UI framework
	// description:
	//		Used to create and run the web workbench and to locate the running
	//		web workbench. Clients must call all methods in a 'static' manner,
	//		e.g.:
	//
	//		net.jazz.ajax.ui.PlatformUI.getWorkbench();
	//
	//		This is an object, not a class, and therefore cannot be
	//		instantiated.

	createAndRunWorkbench: function(applicationId) {
		// summary:
		//		creates and runs the application specified by 'applicationId'
		// description:
		//		he Jazz Ajax Framework calls this function exactly once at the
		//		beginning of the web page's lifecycle
		
		this._workbench = new net.jazz.ajax.ui.Workbench();
		
		this._applicationId = applicationId;
		var RegistryFactory = net.jazz.ajax.core.runtime.RegistryFactory;
		var extensionPoint = RegistryFactory.getRegistry().getExtensionPoint("net.jazz.ajax.applications");
		dojo.forEach(extensionPoint.getExtensions(), function(extension) {
			if (extension.getUniqueIdentifier() == applicationId) {
				dojo.forEach(extension.getConfigurationElements(), function(configElement) {
					if (configElement.getName() !== "application") { return; }
						var appClassName = configElement.getAttribute("jsclass");
						net.jazz.ajax.core.internal.loader.load_sync(appClassName);
						var appConstructor = dojo.getObject(appClassName);
						new appConstructor();
				});
			}
		});
	},
	
	getWorkbench: function() {
		// summary:
		//		Returns a reference to the running the web workbench. Fails if
		//		the web workbench has not been created yet.
		return this._workbench;
	},
	
	//
	// Internal methods; do not call directly
	//
	
	_getApplicationId: function() {
		return this._applicationId;
	}
};