/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("net.jazz.ajax.ui.internal.Dialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.Menu");
dojo.require("dojo.fx");

dojo.require("dojo.i18n"); 
dojo.requireLocalization("net.jazz.ajax.ui.internal", "JAFMessages");

(function() {

//
// Aliases
//
var messages;

dojo.declare("net.jazz.ajax.ui.internal.Dialog",
	[dijit._Widget, dijit._Templated], {

	templatePath: dojo.moduleUrl("net.jazz.ajax", "ui/internal/templates/Dialog.html"),
	
	contentNode: null,  //DOM node for contents of dialog
	width: "40%",		//Optional - zero means natural width, but content scroll bar bugs present when height is fixed
	height: "",			//Optional - zero means natural height
	primaryTitle: "",
	secondaryTitle: "",
	isClosable: true,
	trim: 0,
	showBackground: false,
	modal: true,
	inline: false,
	center: true,  		//true: absolutely position this block in the middle of the screen, false: render it where it is inserted in the dom
	
	onClose: null,		//callback functions
	onOpen: null,
	
	moveable: true,		//not implemented
	iconPath: null, 	//not implemented

	constructor: function(args) {
		messages = dojo.i18n.getLocalization("net.jazz.ajax.ui.internal", "JAFMessages");
	},

	postCreate: function() {
		this.setWidth();
		this.setHeight();
		if (!this.contentNode) {
			this.contentNode = document.createElement("div");
		}
		this._bodyContainer.appendChild(this.contentNode);
		
		this._setTrim(this.trim);
		this._showBackground(this.showBackground);
		
		if (this.primaryTitle) {
			this.setTitle(this.primaryTitle);	
		}
		if (this.secondaryTitle) {
			this.setSecondaryTitle(this.secondaryTitle);	
		}
	
		//add viewlet icon
		this._showIcon();
	
		if (this.isClosable) {
			// create buttons
			if (!this._close) {
				this._close = document.createElement("a");
				this._close.href="#";
				this._close.title = messages.close;
				this._close.className = "close";
				this._headerButtons.appendChild(this._close);
				this.connect(this._close, 'onclick', this.close);
			}
		}
		window.setTimeout(dojo.hitch(this,this._truncate), 1000);
		
		if (this.modal) {
			this.blockerDiv = document.createElement("div");
			this.blockerDiv.className = "net-jazz-ajax-ui-internal-Dialog-blockerDiv";
			this.blockerDiv.style.height = document.body.offsetHeight + "px";
			this.blockerDiv.style.top = document.documentElement.scrollTop + "px";
			this.blockerDiv.style.left = document.documentElement.scrollLeft + "px";
			document.body.appendChild(this.blockerDiv);
		}
		if (this.center){
			this.connect(window, "onresize", this.updatePosition);
			if (dojo.isIE == 6) {
				this.connect(window, "onscroll", dojo.hitch(this,this.updatePosition,true));	
			} else {
				this.connect(window, "onscroll", this.updatePosition);
			}
			dojo.addClass(this._dialog, "net-jazz-ajax-ui-internal-Dialog-absolute");
			this._dialog.style.height = this.height;
			document.body.appendChild(this.domNode);
			setTimeout(dojo.hitch(this,this.updatePosition),0);
		}
		if (this.onOpen && typeof this.onOpen == "function") this.onOpen();
		if (dojo.isIE && this.blockerDiv) this.blockerDiv.style.display = "block";
	},
	updatePosition: function(event, blockerOnly) {
		var de = document.documentElement;
		var height = de.clientHeight;
		var width = de.clientWidth;
		var scrollTop = de.scrollTop;
		var scrollLeft = de.scrollLeft;
		if (this.blockerDiv) {
			this.blockerDiv.style.height = height + "px";
			this.blockerDiv.style.top = scrollTop + "px";
			this.blockerDiv.style.left = scrollLeft + "px";
		}
		
		if (blockerOnly) return;

		this._bodyContainer.style.maxHeight = height - 40 + "px";
		this._dialog.style.maxWidth = width - 40 + "px";
		
		if (this.center) {
			var coords = dojo.coords(this._dialog);
			var top = height / 2 - coords.h / 2 + scrollTop;
			if (top < 10) top = 10;
			var left = width / 2 - coords.w / 2 + scrollLeft;
			if (left < 10) left = 10;
			dojo.marginBox(this._dialog, {l: left, t: top});
		}	
	},
	destroy: function() {
		this.inherited(arguments);
	},
	setWidth: function(/*String with unit*/ width){
		if (width) {
			this._dialog.style.width = width;
			this.width = width;
		} else if (this.width){
			this._dialog.style.width = this.width;
		} else {
			this._dialog.style.width = "";
		}
	},
	setHeight: function(/*String with unit*/ height) {
		if (height) {
			this._bodyContainer.style.height = height;
			this.height = height;
		} else if (this.height) {
			this._bodyContainer.style.height = this.height;
		} else {
			this._bodyContainer.style.height = "";
		}
	},
	setTitle: function(/* string */ title) {
		if (this._headerPrimary.firstChild) {
			this._headerPrimary.replaceChild(document.createTextNode(title),this._headerPrimary.firstChild);	
		} else {
			this._headerPrimary.appendChild(document.createTextNode(title));
		}
		this._truncate(true);
	},
	setSecondaryTitle: function(/* string */ title) {
		this._headerSecondary.innerHTML = title;
		this._truncate(true);
	},
	getSecondaryTitle: function() {
		return this._headerSecondary.innerHTML;
	},
	_setTrim: function(trim) {
		var trimClass;
		if (trim == 1) trimClass = "gray";
		else if (trim == 2) trimClass = "gold";
		else if (trim == 3) trimClass = "green";
		else if (trim == 4) trimClass = "teal";
		else if (trim == 5) trimClass = "purple";
		else if (trim == 6) trimClass = "orange";
		else trimClass = "blue";
		 
		dojo.addClass(this._dialog,trimClass);
		
		this.trim = trim;
		this.trimClass = trimClass;
	},
	_showBackground: function(showBackground) {
		if (showBackground) {
			dojo.addClass(this._contentWrapper,"showBackground");
		} else {
			dojo.removeClass(this._contentWrapper,"showBackground");
		}
	},
	/*
	 * Event handler for onresize truncate call.
	 * Use yielding so that UI is not hung in IE6/7 during truncate's while loop.
	 */ 
	_queueTruncate: function(event) {
		if (!this.truncateTimeout) {
			this.truncateTimeout = setTimeout(dojo.hitch(this,this._truncate),0);
		}
	},
	_truncate: function(force) {
		this.truncateTimeout = null;
		var node = this._headerPrimary;
		// force is used when the title has been changed and the truncate algorithm needs to be run
		// even if the clientWidth is the same
		// force == true is used since this function is called from many places, some of which
		// pass in parameters
		if (force == true || (this._titleIsTruncated && document.body.clientWidth > this._prevWidth)) {
			node.innerHTML = this.primaryTitle;
			this._titleIsTruncated = false;
			node.title = "";
		}
		if (this._headerText.clientHeight > 16) {
			var title = node.innerHTML;
			while (this._headerText.clientHeight > 16) {
				title = title.substring(0,title.length-1);
				while (title.lastIndexOf(" ") == title.length-1)
					title = title.substring(0,title.length-1);
				node.innerHTML = title + "...";
				if (node.innerHTML.length <= 6) break;
			}
			node.title = this.primaryTitle;
			this._titleIsTruncated = true;
			this._prevWidth = document.body.clientWidth;
		}
	},
	/*
	 * Called when the user clicks on the viewlet container's close button.
	 */
	close: function(event) {
		if (event) {
			dojo.stopEvent(event);
		}
		// remove the blocker div
		if (this.blockerDiv && this.blockerDiv.parentNode)
			this.blockerDiv.parentNode.removeChild(this.blockerDiv);
		
		// call onClose callback function, if it exists
		if (this.onClose && typeof this.onClose == "function") this.onClose();
		
		if (dojo.isIE == 7) {
			//IE7 does not fadeOut alpha PNG drop shadows properly (shows ugly black bars) - so just close it
			this._onClose();
		} else {
			//fadeOut
			var args = {node: this._dialog, duration: 200};
			var fadeOut = dojo.fadeOut(args);
			this.connect(fadeOut, "onEnd", this._onClose);
			fadeOut.play();
		}
	},
	_onClose: function() {
		if (this.domNode && this.domNode.parentNode) {
			this.domNode.parentNode.removeChild(this.domNode);	
		}
		this.destroyRecursive();
	},
	_showIcon: function() {
		var icon = this.iconPath;
		if (!icon) {
			return;
		}
		var iconImage = document.createElement("img");
		iconImage.src = icon;
		iconImage.className = "icon-image";
		this._headerIcon.appendChild(iconImage);
	}
});

})();
