/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.repository.web.ui.internal.Navbar");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.Menu");
dojo.require("dojo.i18n");

dojo.require("net.jazz.ajax.toolbox.lang.internal.Lang");
dojo.require("net.jazz.ajax.ui.PageList");

dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.ui.internal.Login");
dojo.require("com.ibm.team.repository.web.ui.internal.Logout");
dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.client.internal.ServerStatusClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.ui.internal.Util");
dojo.require("com.ibm.team.repository.web.ui.internal.about.AboutJazzTeamServer");

dojo.requireLocalization("com.ibm.team.repository.web.ui.internal", "NavbarMessages");

/**
 * Provides the web UI's header area.
 */
var checkNotNull 	            = net.jazz.ajax.toolbox.lang.checkNotNull;
var isGuest 					= com.ibm.team.repository.web.client.session.isGuest;
var InitializationData			= com.ibm.team.repository.web.client.init.InitializationData;
var ServerStatusClient			= com.ibm.team.repository.web.client.internal.ServerStatusClient;
var ServiceResponseHandler		= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var X_AUTH_MSG					= "X-com-ibm-team-repository-web-auth-msg";
var Util						= com.ibm.team.repository.web.ui.internal.Util;

function getHomeUri() {
	if(com.ibm.team.repository.web.homeuri) {
		return com.ibm.team.repository.web.homeuri;
	}
	return null;
}

function getProjectAreasLinkElement() {
	var projectAreasLinkElement = document.createElement("a");
	
	if (!Util.isProjectAreaApplication()) {
		projectAreasLinkElement.href = "#action=jazz.viewPage&id=com.ibm.team.process.projectAreaList";
	} else {
		projectAreasLinkElement.href = net.jazz.ajax._contextRoot + "/web";
	}
	projectAreasLinkElement.className = "projectAreas";
			
	var innerWrapper = document.createElement("div");
	innerWrapper.className = "innerWrapper";
	var outerWrapper = document.createElement("div");
	outerWrapper.className = "outerWrapper";
	innerWrapper.innerHTML = messages.projectAreas;
	outerWrapper.appendChild(innerWrapper);
	projectAreasLinkElement.appendChild(outerWrapper);
	
	return projectAreasLinkElement;
}

function getAdminLinkElement() {
	var adminLinkElement = document.createElement("a");
	adminLinkElement.href = dojo.baseUrl + "../../admin";
	adminLinkElement.className = "admin";
		
	var innerWrapper = document.createElement("div");
	innerWrapper.className = "innerWrapper";
	var outerWrapper = document.createElement("div");
	outerWrapper.className = "outerWrapper";
	innerWrapper.innerHTML = messages.admin;
	outerWrapper.appendChild(innerWrapper);
	adminLinkElement.appendChild(outerWrapper);

	return adminLinkElement;
}

function getHomeLinkElement() {
	checkNotNull(getHomeUri(), "getHomeUri()");
	
	var homeLinkElement = document.createElement("a");
	
	homeLinkElement.href = getHomeUri();
	homeLinkElement.className = "home";
	
	var innerWrapper = document.createElement("div");
	innerWrapper.className = "innerWrapper";
	var outerWrapper = document.createElement("div");
	outerWrapper.className = "outerWrapper";
	innerWrapper.innerHTML = messages.home;
	outerWrapper.appendChild(innerWrapper);
	homeLinkElement.appendChild(outerWrapper);
	
	return homeLinkElement;
}

dojo.declare("com.ibm.team.repository.web.ui.internal.Navbar", [dijit._Widget, dijit._Templated], {
	
	//
	// Module-private properties and methods
	//

	templatePath: dojo.moduleUrl("com.ibm.team.repository.web", "ui/internal/templates/Navbar.html"),
	
	showLoginPanel: false,
	
	constructor: function () {
		this.messages = messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.internal", "NavbarMessages");
	},
		
	/**
	 * Fill in the dynamic elements of the header nav.
	 */
	postCreate: function() {
		if (this.suppressedPages == null) {
			this.suppressedPages = [];
		}
		this.suppressedPages.push("com.ibm.team.process.projectAreaList");
		this._linksAdded = false;
		var pageList = this._createPageList();
		if(this.showLoginPanel) {
			if(getHomeUri()) {
				this._addHomeLinks();
			}
			if (Util.isProjectAreaApplication()) {
				this._addProjectAreasLink(false, false);
			} else {
				this._addProjectAreasLink(false, true);
			}
			this.pageListContainer.appendChild(pageList.domNode);
			if (Util.isAdminUI()) {
				//this._addAdminLink(true);
			} else if (Util.userIsAdmin()) {
				this._addAdminLink(false);
			}
			this._linksAdded = true;
		} else {
			this.pageListContainer.appendChild(pageList.domNode);
		}
	},
	
	_createPageList: function() {
		var args = this.suppressedPages ?
			{suppressedPages: this.suppressedPages} : {};
		var pageList = new net.jazz.ajax.ui.PageList(args);
		this.connect(pageList,"_selectPage", function (page) {
			if (this.projectAreasLink) {
				if (page.id === "com.ibm.team.process.projectAreaList") {
					dojo.toggleClass(this.projectAreasLink, "selected", true);
				} else {
					dojo.toggleClass(this.projectAreasLink, "selected", false);
				}
			}
		});
		return pageList;
	},
	
	_addHomeLinks: function() {
		var homeLinkElement = getHomeLinkElement();
		var ul = document.createElement("ul");
		var li = document.createElement("li");
		li.className = "rightSeparator";
		li.appendChild(homeLinkElement);
		ul.appendChild(li);
		dojo.toggleClass(ul, "net-jazz-ajax-PageList", true);
		this.pageListContainer.appendChild(ul);
	},
	
	_addAdminLink: function(selected) {
		var adminLinkElement = getAdminLinkElement();
		if (selected)
			dojo.addClass(adminLinkElement,"selected");
		var ul = document.createElement("ul");
		ul.className = "linkFloatRight";
		var li = document.createElement("li");
		li.className = "leftSeparator";
		li.appendChild(adminLinkElement);
		ul.appendChild(li);
		dojo.toggleClass(ul, "net-jazz-ajax-PageList", true);
		this.pageListContainer.appendChild(ul);
		
		var serverInfo = InitializationData.get("com.ibm.team.repository.service.serverInfoInitializer");
		if (serverInfo != null && serverInfo.servicesInitSuccess > 0 || !serverInfo.repoInitSuccess) {
			var errCount = serverInfo.servicesInitSuccess;
			if (!serverInfo.repoInitSuccess) {
				errCount++;
			}
			if (errCount > 0) {
				var span = document.createElement("span");
				span.appendChild(document.createTextNode(" (" + errCount + ")"));
				span.style.fontWeight = "normal";
				adminLinkElement.firstChild.firstChild.appendChild(span);
			}
		}
	},
	
	_addProjectAreasLink: function(showLeftSeparator, showRightSeparator) {
		var projectAreasLinkElement = getProjectAreasLinkElement();
		this.projectAreasLink = projectAreasLinkElement;
		var ul = document.createElement("ul");
		var li = document.createElement("li");
		if (showLeftSeparator)
			li.className = "leftSeparator";
		if (showRightSeparator)
			li.className = "rightSeparator";
		li.appendChild(projectAreasLinkElement);
		ul.appendChild(li);
		dojo.toggleClass(ul, "net-jazz-ajax-PageList", true);
		this.pageListContainer.appendChild(ul);
	},
	_onHelpButtonClick: function(event) {
		dojo.stopEvent(event); //never want this click to bubble - its only purpose is to open the help menu.		

		//calculate the position of the drop down menu
		var pos = dojo.coords(this.pageListContainer, true);
		
		//Display menu
		if (!this._helpMenu)
			this._createDropDown();
			
		if (dojo.isIE) var offset = 7;
		else var offset = 6;
		
		dijit.popup.open({ popup: this._helpMenu, x: pos.x + pos.w + 1, y: pos.y + pos.h - offset, parent: this, onExecute: dojo.hitch(this,this.closeDropDown), orient: 'TR' });
		
		//register event handlers that cause menu to close
		this._menuCloseOnBody = this.connect(this,"_onBlur",this.closeDropDown);
		
		//style menu icon to indicate open state
		dojo.addClass(this.helpButton,"menu-open");

	},
	_createDropDown: function (){
		if (this._helpMenu) {
			this._helpMenu.destroy();
		}
		var menu = new dijit.Menu({"class":"aboutMenu"});
		var helpuri = com.ibm.team.repository.web.helpuri;
		if (helpuri) {
			this.helpuri = helpuri;
			menu.addChild(new dijit.MenuItem({label: this.messages.helpContents, iconClass: 'helpIcon', onClick: dojo.hitch(this,this._openHelpContents)}));
		}
		
		if (Util.isAdminUI())
			menu.addChild(new dijit.MenuItem({label: this.messages.aboutJTS, onClick: dojo.hitch(this,this.openAboutBox)}));
		else
			menu.addChild(new dijit.MenuItem({label: this.messages.aboutRTC, onClick: dojo.hitch(this,this.openAboutBox)}));
		this._helpMenu = menu;
	},
	_openHelpContents: function(event) {
		if (this.helpuri)
			window.open(this.helpuri,'help');
	},
	closeDropDown: function(event) {
		this.disconnect(this._menuCloseOnBody);
		this._menuCloseOnBody = null;
		dojo.removeClass(this.helpButton,"menu-open");
		dijit.popup.close(this._helpMenu);
	},
	openAboutBox: function(){
		if (Util.isAdminUI())
			new com.ibm.team.repository.web.ui.internal.about.AboutJazzTeamServer({dialogTitle: this.messages.aboutJTS});
		else
			new com.ibm.team.repository.web.ui.internal.about.AboutJazzTeamServer({dialogTitle: this.messages.aboutRTC});
	}
});

})();
