/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.repository.web.ui.internal.admin.util");

function prepad2(number){
	if (number < 10){
		return "0" + number;
	}
	return number;
}

function prepad3(number){
	var result = prepad2(number);
	if (number < 100){
		result = "0" + result;
	} 
	return result;
}

function separateUnitLabels(label1, label2){
	var result = "";
	if (label1.length > 0) {
		result = label1;
	}
	if (label1.length > 0 && label2.length > 0){
		result = result + ", ";
	}
	if (label2.length > 0) {
		result = result + label2;
	}
	return result;
}

function formatUnitLabel(value, singularLabel, pluralLabel) {
	switch (value){
		case 0:
			return "";
		case 1:
			return "1 " + singularLabel;
		default:
			return value + " " + pluralLabel;		
	}
}

function formatTimeFromMilliseconds(ms) {
	var time = ms;
	
	var milli = time%1000;
	var formatString = prepad3(milli);
	time = Math.floor(time/1000);
	
	var seconds = time%60;
	formatString = prepad2(seconds) + ":" + formatString;
	time = Math.floor(time/60);
	
	var minutes = time%60;
	formatString = prepad2(minutes) + ":" + formatString;
	time = Math.floor(time/60);
	
	var hours = time%24;
	formatString = prepad2(hours) + ":" + formatString;
	time = Math.floor(time/24);
	
	if (time > 0){
		formatString = time + " days, " + formatString;
	}
	return formatString;
}

com.ibm.team.repository.web.ui.internal.admin.util.formatTimeFromMilliseconds = formatTimeFromMilliseconds;

function formatDaysHoursMinsFromMilliseconds(ms) {
	var time = ms;
	var formatString = "";
	
	//drop ms
	time = Math.floor(time/1000);
	//drop sec
	time = Math.floor(time/60);
	
	var minutes = time%60;
	if (time < 1){
		return "less than 1 minute";
	}
	formatString = formatUnitLabel(minutes, "minute", "minutes");
	time = Math.floor(time/60);
	
	var hours = time%24;
	var hourLabel = formatUnitLabel(hours, "hour", "hours");
	formatString = separateUnitLabels(hourLabel, formatString);
	time = Math.floor(time/24);
	var dayLabel = formatUnitLabel(time, "day", "days");
	formatString = separateUnitLabels(dayLabel, formatString);
	
	return formatString;
}

com.ibm.team.repository.web.ui.internal.admin.util.formatDaysHoursMinsFromMilliseconds = formatDaysHoursMinsFromMilliseconds;

function formatSizeFromBytes(bytes) {
	var size = bytes;
	var CONVERSION = 1024;
	var formatString = "";
	
	//1 kilobytes = 1024 bytes
	var b = size%CONVERSION;
	size = Math.floor(size/CONVERSION);
	
	//1 megabytes = 1024 kilobytes
	var kb = size%CONVERSION;
	size = Math.floor(size/CONVERSION);
	
	var mb = size;
	
	if (mb < 1){
		formatString = kb + " KB";
	} else {
		formatString = mb + " MB";
	}
	return formatString;
}

com.ibm.team.repository.web.ui.internal.admin.util.formatSizeFromBytes = formatSizeFromBytes;

function replaceNewLineWithBreak(text){
	return text.replace(/\n/g, "<br>"); 
}

com.ibm.team.repository.web.ui.internal.admin.util.replaceNewLineWithBreak = replaceNewLineWithBreak;

function replaceNewLineWithPaddedBreaks(text, prepend){
	var result = text.replace(/\n/g, "<br>&nbsp;&nbsp;&nbsp;"); 
	if (prepend) {
		//pad with actual spaces so copy/paste of a stacktrace preserves some formatting
		result = "&nbsp;&nbsp;&nbsp;" + result;
	}
	return result;
}

com.ibm.team.repository.web.ui.internal.admin.util.replaceNewLineWithPaddedBreaks = replaceNewLineWithPaddedBreaks;

function arrayIndexOfObject(array, match) {
	var index = -1;
	if(array != null && match != null) {
		for (var i=0; i<array.length; i++) {
			if (match === array[i]) { return i; }
		}
	}
	return index;
}

com.ibm.team.repository.web.ui.internal.admin.util.arrayIndexOfObject = arrayIndexOfObject;

function arrayIndexWithPropertyOfObject(array, property, match) {
	var index = -1;
	if(array != null && match != null && property != null) {
		for (var i=0; i<array.length; i++) {
			if (match === array[i][property]) { return i; }
		}
	}
	return index;
}

com.ibm.team.repository.web.ui.internal.admin.util.arrayIndexWithPropertyOfObject = arrayIndexWithPropertyOfObject;


function arrayContainsObject(array, match) {
	if(arrayIndexOfObject(array, match) > -1) {
		return true;
	}
	return false;
}

com.ibm.team.repository.web.ui.internal.admin.util.arrayContainsObject = arrayContainsObject;

function convertDateStringToRelativeTimeString(dateString) {
	var suffix = "";
	if (diff < 0) {
		diff = diff * -1;
		suffix = " ago";
	}
	
	var date = dojo.date.stamp.fromISOString(dateString);
	var diff = dojo.date.difference(new Date(), date, "minute");
	var timeLeftQualifier = "minutes";
	if (diff > 0) {
		timeLeftQualifier = "minutes";
	} else {
		diff = dojo.date.difference(new Date(), date, "second");
		if (diff > 0) {
			timeLeftQualifier = "seconds";
		} else {
			diff = dojo.date.difference(new Date(), date, "millisecond");
			timeLeftQualifier = "milliseconds";
		}
	}
	
	return diff + " " + timeLeftQualifier + suffix;
}

com.ibm.team.repository.web.ui.internal.admin.util.convertDateStringToRelativeTimeString = convertDateStringToRelativeTimeString;


})();