/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.repository.web.ui.internal.wizard.WizardApplication");

dojo.require("net.jazz.ajax.ui._Application");
dojo.require("net.jazz.ajax.ui.PageContainer");
dojo.require("net.jazz.ajax.ui.PageList");
dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("net.jazz.ajax.ui.ProgressIndicator");
dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.client.internal.RepositoryClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.internal.ProvisionResponseHandler");
dojo.require("com.ibm.team.repository.web.client.internal.ProvisioningClient");
dojo.require("dojo.i18n");

dojo.requireLocalization("com.ibm.team.repository.web.ui.internal.wizard", "WizardApplicationMessages");

function workbenchRootNode(){
	return net.jazz.ajax.ui.PlatformUI.getWorkbench().rootNode();
}

var InitializationData      = com.ibm.team.repository.web.client.init.InitializationData;
var RepositoryClient 		= com.ibm.team.repository.web.client.internal.RepositoryClient;
var SRH	= com.ibm.team.repository.web.transport.ServiceResponseHandler
var ProvisioningClient = com.ibm.team.repository.web.client.internal.ProvisioningClient;
var ProvisionResponseHandler = com.ibm.team.repository.web.transport.internal.ProvisionResponseHandler;


dojo.declare("com.ibm.team.repository.web.ui.internal.wizard.WizardApplication", net.jazz.ajax.ui._Application, {
	
	constructor: function() {
		this.messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.internal.wizard", "WizardApplicationMessages");
	},

	init: function() {
		// fetch quick secured command to require ADMIN auth.  
		// can't use Util.userIsAdmin since it's false for everyone if DB is down
		var prh = new ProvisionResponseHandler(this, "authRequestPassed", "authRequestFailed");
		ProvisioningClient.isRepositoryAvailable(prh);		
	},	

	_startApp: function () {
		this._createUI();
		this.setName(this.messages.setupName);
		this.start();
	},
	
	_createUI: function() {		
		dojo.addClass(workbenchRootNode(), "com-ibm-team-repository-web-setup-RootNode");
		
		// create the page container and append it to the document body
		var pageArea = new net.jazz.ajax.ui.PageContainer();
		workbenchRootNode().appendChild(pageArea.domNode);
		
		// create the progress indicator
		// note: progress indicator styles defined in resources/ui/styles.css
		var progressIndicator = new net.jazz.ajax.ui.ProgressIndicator();
		pageArea.domNode.appendChild(progressIndicator.domNode);
		progressIndicator.domNode.className = "net-jazz-ajax-examples-ProgressIndicator";
	},
	
	authRequestPassed: function() {
		RepositoryClient.getInitializationData(new SRH(this, "_handleInitData", "_fetchInitDataFailed"));
	},
	
	authRequestFailed: function(errorObject) {
		dojo.setObject("com.ibm.team.repository.web.noAdminAuth", "not authorized");
		RepositoryClient.getInitializationData(new SRH(this, "_handleInitData", "_fetchInitDataFailed"));
	}, 
	
		
	_handleInitData: function(initData) {
		InitializationData._load(initData);
		// handle case where there is no DB so contributor isn't in init data
		if (InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer") != null) {
			dojo.setObject("com.ibm.team.repository.web.client.internal.AUTHENTICATED_CONTRIBUTOR", InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer").currentContributor);
		}
		// store the configuration properties in global vars with corresponding names
/*
		var configProperties = InitializationData.get("com.ibm.team.repository.service.configPropertyInitializer");
		for (var propName in configProperties) {
			var propVal = configProperties[propName];
			dojo.setObject(propName, propVal);
		}	
*/	
		// store the license behavior in global vars
		if (InitializationData.get("com.ibm.team.repository.service.assertLicenseInitializer") != null) {
			var licenseBehavior = InitializationData.get("com.ibm.team.repository.service.assertLicenseInitializer");
			for (var propName in licenseBehavior) {
				var propVal = licenseBehavior[propName];
				dojo.setObject(propName, propVal);
				//alert(propName + ": " + propVal);
			}		
		}
		this._startApp();
	},
		
	_fetchInitDataFailed: function(errorObject) {	
		this._startApp();
	}
	
});

})();